@@ -598,7 +598,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
         from calibre.gui2.dialogs.confirm_merge import confirm_merge
         if self.gui.current_view() is not self.gui.library_view:
             return
-        rows = self.gui.library_view.indices_for_merge()
+        rows = self.gui.library_view.rows_for_merge()
         if not rows or len(rows) == 0:
             return error_dialog(self.gui, _('Cannot merge books'),
                                 _('No books selected'), show=True)
@@ -809,7 +809,7 @@ class EditMetadataAction(InterfaceActionWithLibraryDrop):
                 old_tags = db.tags(book_id, index_is_id=True)
                 if old_tags:
                     tags = [x.strip() for x in old_tags.split(',')] + (
-                            mi.tags if mi.tags else [])
+                            mi.tags or [])
                     mi.tags = list(set(tags))
             if self._am_merge_comments:
                 old_comments = db.new_api.field_for('comments', book_id)
