@@ -39,7 +39,6 @@ from calibre.gui2 import error_dialog
 from calibre.gui2.device_drivers.mtp_folder_browser import Browser, IgnoredFolders
 from calibre.gui2.dialogs.template_dialog import TemplateDialog
 from calibre.utils.date import parse_date
-from polyglot.builtins import iteritems
 
 # We allow users to configure rules for sending audio book files as well
 BOOK_EXTENSIONS = frozenset(EBOOK_EXTENSIONS) | {'mp3', 'aac', 'aax', 'm4a', 'm4b'}
@@ -198,8 +197,7 @@ class IgnoredDevices(QWidget):  # {{{
         self.f = f = QListWidget(self)
         l.addWidget(f)
 
-        devs = [(snum, (x[0], parse_date(x[1]))) for snum, x in
-                iteritems(devs)]
+        devs = [(snum, (x[0], parse_date(x[1]))) for snum, x in devs.items()]
         for dev, x in sorted(devs, key=lambda x:x[1][1], reverse=True):
             name = x[0]
             name = f'{name} [{dev}]'
