@@ -411,6 +411,7 @@ def run_gui_(opts, args, app, gui_debug=None):
         actions = tuple(Main.get_menubar_actions())
     runner = GuiRunner(opts, args, actions, app, gui_debug=gui_debug)
     ret = app.exec()
+    timed_print('Application event loop quit')
     if getattr(runner.main, 'run_wizard_b4_shutdown', False):
         from calibre.gui2.wizard import wizard
         wizard().exec()
@@ -450,26 +451,32 @@ class FailedToCommunicate(Exception):
     pass
 
 
-def send_message(msg, retry_communicate=False):
+def send_message(msg):
+    fail_err = None
     try:
         send_message_in_process(msg)
+        return True
     except Exception:
-        time.sleep(2)
-        try:
-            send_message_in_process(msg)
-        except Exception as err:
-            # can happen because the Qt local server pipe is shutdown before
-            # the single instance mutex is released
-            if retry_communicate:
-                raise FailedToCommunicate('retrying')
-            print(_('Failed to contact running instance of calibre'), file=sys.stderr, flush=True)
-            print(err, file=sys.stderr, flush=True)
-            if Application.instance():
-                error_dialog(None, _('Contacting calibre failed'), _(
-                    'Failed to contact running instance of calibre, try restarting calibre'),
-                    det_msg=str(err) + '\n\n' + repr(msg), show=True)
-            return False
-    return True
+        # can happen if Qt LocalServer has not yet started, typically happens on Windows
+        st = time.monotonic()
+        while time.monotonic() - st < 6:
+            try:
+                send_message_in_process(msg)
+                return True
+            except Exception as err:
+                fail_err = err
+                time.sleep(0.05)
+                with SingleInstance(singleinstance_name) as si:
+                    if si:
+                        raise SystemExit(_('Other instance of calibre shutdown'))
+
+    print(_('Failed to contact running instance of calibre'), file=sys.stderr, flush=True)
+    print(fail_err, file=sys.stderr, flush=True)
+    if Application.instance():
+        error_dialog(None, _('Contacting calibre failed'), _(
+            'Failed to contact running instance of calibre, try restarting calibre'),
+            det_msg=str(fail_err or '') + '\n\n' + repr(msg), show=True)
+    return False
 
 
 def shutdown_other():
@@ -483,7 +490,7 @@ def shutdown_other():
         raise SystemExit(_('Failed to shutdown running calibre instance'))
 
 
-def communicate(opts, args, retry_communicate=False):
+def communicate(opts, args):
     if opts.shutdown_running_calibre:
         shutdown_other()
     else:
@@ -493,7 +500,7 @@ def communicate(opts, args, retry_communicate=False):
             library_id = os.path.basename(opts.with_library).replace(' ', '_').encode('utf-8').hex()
             args.insert(1, 'calibre://switch-library/_hex_-' + library_id)
         import json
-        if not send_message(b'launched:'+as_bytes(json.dumps(args)), retry_communicate=retry_communicate):
+        if not send_message(b'launched:'+as_bytes(json.dumps(args))):
             raise SystemExit(_('Failed to contact running instance of calibre'))
     raise SystemExit(0)
 
@@ -543,28 +550,41 @@ def main(args=sys.argv):
         app, opts, args = init_qt(args)
     except AbortInit:
         return 1
-    try:
-        with SingleInstance(singleinstance_name) as si:
-            if si and opts.shutdown_running_calibre:
-                return 0
-            run_main(app, opts, args, gui_debug, si, retry_communicate=True)
-    except FailedToCommunicate:
-        with SingleInstance(singleinstance_name) as si:
-            if si and opts.shutdown_running_calibre:
-                return 0
-            run_main(app, opts, args, gui_debug, si, retry_communicate=False)
+    with SingleInstance(singleinstance_name) as si:
+        if si and opts.shutdown_running_calibre:
+            return 0
+        run_main(app, opts, args, gui_debug, si)
     if after_quit_actions['restart_after_quit']:
         restart_after_quit()
     sip.delete(app)
     del app
     import gc
     gc.collect(), gc.collect()
+    if iswindows:
+        # On Windows we get a mysterious deadlock that hangs the process on
+        # exit even if we call os._exit(0), once the wireless device driver connects.
+        # See https://bugs.launchpad.net/bugs/2141994
+        # Started in calibre 9 probably because of a new regression in Python/Qt
+        # Getting process properties via process explorer causes the process to exit.
+        # So it is likely a hang in the Loader Lock. Or memory corruption during exit.
+        # So we run the atexit handlers now and then exit using TerminateProcess
+        # This breaks cleanup code in non python DLLs and Py_AtExit. Cant be helped.
+        # At least worker process still seem to be closed.
+        from calibre.devices.smart_device_app.driver import wireless_driver_connected
+        if wireless_driver_connected:
+            import atexit
+            atexit._run_exitfuncs()
+            atexit._clear()
+            import ctypes
+            handle = ctypes.windll.kernel32.OpenProcess(0x0001, False, os.getpid())
+            # Terminate immediately This does NOT return; the process is gone the moment this is called.
+            ctypes.windll.kernel32.TerminateProcess(handle, 0)
 
 
-def run_main(app, opts, args, gui_debug, si, retry_communicate=False):
+def run_main(app, opts, args, gui_debug, si):
     if si:
         return run_gui(opts, args, app, gui_debug=gui_debug)
-    communicate(opts, args, retry_communicate)
+    communicate(opts, args)
     return 0
 
 
