@@ -11,7 +11,7 @@ import traceback
 from collections import defaultdict
 from contextlib import suppress
 from copy import deepcopy
-from functools import partial
+from functools import lru_cache, partial
 
 from calibre.constants import CONFIG_DIR_MODE, config_dir, filesystem_encoding, get_umask, iswindows, preferred_encoding
 from calibre.utils.localization import _
@@ -630,11 +630,30 @@ def normalize_tweak(val):
     return val
 
 
+def parse_python_tweaks(text: str) -> dict[str, object]:
+    import ast
+    ans = {}
+    tree = ast.parse(text, filename='<string>')
+    for node in tree.body:
+        if isinstance(node, ast.Assign):
+            # Get the value (must be a literal)
+            try:
+                value = ast.literal_eval(node.value)
+            except Exception:
+                # Skip non-literal values
+                continue
+            # Extract target variable names
+            for target in node.targets:
+                if isinstance(target, ast.Name):
+                    ans[target.id] = value
+    return ans
+
+
 def write_custom_tweaks(tweaks_dict):
     make_config_dir()
     tweaks_dict = make_unicode(tweaks_dict)
     changed_tweaks = {}
-    default_tweaks = exec_tweaks(default_tweaks_raw())
+    default_tweaks = parse_python_tweaks(default_tweaks_raw())
     for key, cval in tweaks_dict.items():
         if key in default_tweaks and normalize_tweak(cval) == normalize_tweak(default_tweaks[key]):
             continue
@@ -644,21 +663,6 @@ def write_custom_tweaks(tweaks_dict):
         f.write(raw)
 
 
-def exec_tweaks(path):
-    if isinstance(path, bytes):
-        raw = path
-        fname = '<string>'
-    else:
-        with open(path, 'rb') as f:
-            raw = f.read()
-            fname = f.name
-    code = compile(raw, fname, 'exec')
-    l = {}
-    g = {'__file__': fname}
-    exec(code, g, l)
-    return l
-
-
 def read_custom_tweaks():
     make_config_dir()
     tf = tweaks_file()
@@ -677,18 +681,20 @@ def read_custom_tweaks():
             return ans
     old_tweaks_file = tf.rpartition('.')[0] + '.py'
     if os.path.exists(old_tweaks_file):
-        ans = exec_tweaks(old_tweaks_file)
+        with open(old_tweaks_file) as f:
+            ans = make_unicode(parse_python_tweaks(old_tweaks_file))
         ans = make_unicode(ans)
         write_custom_tweaks(ans)
     return ans
 
 
+@lru_cache
 def default_tweaks_raw():
-    return P('default_tweaks.py', data=True, allow_user_override=False)
+    return P('default_tweaks.py', data=True, allow_user_override=False).decode()
 
 
 def read_tweaks():
-    default_tweaks = exec_tweaks(default_tweaks_raw())
+    default_tweaks = parse_python_tweaks(default_tweaks_raw())
     try:
         custom_tweaks = read_custom_tweaks()
     except Exception:
@@ -713,7 +719,7 @@ migrate_tweaks_to_prefs()
 
 
 def reset_tweaks_to_default():
-    default_tweaks = exec_tweaks(default_tweaks_raw())
+    default_tweaks = parse_python_tweaks(default_tweaks_raw())
     tweaks.clear()
     tweaks.update(default_tweaks)
 
@@ -729,3 +735,14 @@ class Tweak:
 
     def __exit__(self, *args):
         tweaks[self.name] = self.origval
+
+
+def find_tests():
+    import unittest
+    class TestTweakParsing(unittest.TestCase):
+        def test_tweak_parsing(self):
+            for raw in (default_tweaks_raw(),):
+                expected, g = {}, {}
+                exec(raw, g, expected)
+                self.assertEqual(expected, parse_python_tweaks(raw))
+    return unittest.defaultTestLoader.loadTestsFromTestCase(TestTweakParsing)
